import { select, 
        json,
        csv,
        tsv, 
        geoPath,
        geoMercator,
        scaleOrdinal,
        schemeCategory10,
        zoom,
        event } from 'd3';
import { feature } from 'topojson';

const svg = select('svg');
const width = parseFloat(svg.attr('width'));
const height = +svg.attr('height');
let stateNames = [];

//using geoMercator() projection for the china map
const projection = geoMercator()
			.clipExtent([[0,0],[width,height]])
			.center([100, 30]) // setting the position
			.scale(400); //size of the map

const pathGenerator = geoPath()
		.projection(projection);

const g = svg.append('g');

svg.call(zoom().on('zoom', () => {
	g.attr('transform', event.transform)
}));

//we are getting the geo-data from the gist
// we can also use our gist

Promise.all([json('https://gist.githubusercontent.com/anushaanumula/0bbcb60edf35b5d44f2cfe1bee43ddd1/raw/960f59b3da6296e27bf3bdec8a29de9b6c27e998/chinamap_data.json'),
             json('https://gist.githubusercontent.com/anushaanumula/0bbcb60edf35b5d44f2cfe1bee43ddd1/raw/960f59b3da6296e27bf3bdec8a29de9b6c27e998/chinamap_data.json')
            ]).then(([stateJSON, districtJSON]) => {
  const districtGroup = g.append('g')
  const stateGroup = g.append('g');
  
  //const districts = feature(districtJSON, districtJSON.objects['china-provinces-simplified']);			
  const states = feature(stateJSON, stateJSON.objects.CHN_adm1);
  
  const colorScale = scaleOrdinal(schemeCategory10);

  const statePath = stateGroup.selectAll('path')
    .data(states.features)
  statePath.enter().append('path')
    .attr('class', 'states')
    .attr('d', d => pathGenerator(d))
});
   